<?xml version="1.0" encoding="utf-8"?>

<!-- PRODUCT: XML data to a HTML view formatting
 
 Bertrand Le Quellec (c) 2014-2021
 
 Version: 1.1 English Release - Created: 2014-11-27

 Changed: 2021-10-03
 Changed: 2016-03-20 - prise en charge des labels des statuts sur Historique-Evènement
 Changed: 2016-03-26 - correction affichage liens externe
 
 Description:
 A generic Xml file from one Xml object data formatting Xsl file,
 representative structure a Product or Service.
 -->

<xsl:stylesheet id="stylesheet" version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  
  <!-- The variables indicating the Page Settings. -->
  <xsl:variable name="margin"              select="'2px'" />
  <xsl:variable name="padding"             select="'5px'" />
  <xsl:variable name="background_color"    select="'#F4FAFC'" />
  <xsl:variable name="font_size"           select="'75%'" />
  <xsl:variable name="font_family"         select="'Verdana, Geneva, Tahoma, sans-serif'" />

  <!-- The variables designating colours. -->
  <xsl:variable name="legendtop_color"     select="'Lavender'" />
  <xsl:variable name="legendleft_color"    select="'#B8CCEE'" />
  <xsl:variable name="rowseparator_color"  select="'Black'" />
  <xsl:variable name="content_color"       select="'#B8CCDC'" />
  <xsl:variable name="comment_color"       select="'#ffebcd'" />
  <xsl:variable name="actionleft_color"    select="'lightgrey'" />

  <!-- The variables for the formatting of the main tables. -->
  <xsl:variable name="table_color"         select="'#ffffff'" />
  <xsl:variable name="table_border"        select="'0'" />
  <xsl:variable name="table_spacing"       select="'1'" />
  <xsl:variable name="table_padding"       select="'0'" />
  <xsl:variable name="table_font"          select="'normal serif'" />

  <!-- The variables for the formatting of secondary tables. -->
  <xsl:variable name="table2_color"         select="'#ffffff'" />
  <xsl:variable name="table2_border"        select="'0'" />
  <xsl:variable name="table2_spacing"       select="'1'" />
  <xsl:variable name="table2_padding"       select="'0'" />

  <!-- The formatting of the html output method. -->
  <xsl:output
   method="html"
   encoding="ISO-8859-1"
   doctype-public="-//W3C//DTD HTML 4.01//EN"
   doctype-system="http://www.w3.org/TR/html4/strict.dtd"
   indent="yes" />

  <!-- Body of the HTML result: starting point. -->
  <xsl:template match="/">
    <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en">

      <head>
        <title>
          <xsl:value-of disable-output-escaping="yes" select="Product/Name" /> <xsl:value-of disable-output-escaping="yes" select="Product/Reference" />
        </title>
        <meta name="description" content="Contact Manager - Product" />

        <meta name="publisher" content="BLQ software" />
        <meta name="author" content="BLQ software" />
        <meta name="copyright" content="BLQ software" />

        <meta name="http.language" content="English" />
        <meta name="Language" content="EN" />
        <meta http-equiv="Content-Language" content="en" />
      </head>

      <body style="margin:{$margin}; padding:{$padding}; background-color:{$background_color}; font-size:{$font_size}; font-family:{$font_family}; ">
        <!-- ********************************************
            Processing of the Xml root named Product 
           ******************************************** -->
        <xsl:apply-templates select="Product" />
      </body>
    </html>
  </xsl:template>

  <!-- 
   ===========================================
    COMPANY: first-level Xml processing 
   =========================================== -->
  <xsl:template match="Product">

    <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">
      <tr>
        <th width="40%" align="left">
          <font size="+1">
            <b>
              <xsl:choose>
                <xsl:when test="Rank= '4'">
                  <xsl:text>* * * *</xsl:text>
                </xsl:when>
                <xsl:when test="Rank= '3'">
                  <xsl:text>* * *</xsl:text>
                </xsl:when>
                <xsl:when test="Rank= '2'">
                  <xsl:text>* *</xsl:text>
                </xsl:when>
                <xsl:when test="Rank= '1'">
                  <xsl:text>*</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                  <!-- Inserting a space -->
                  <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </b>
          </font>
        </th>

        <!-- CREATION DATE -->
        <th align="right">
          <font size="-2">
            <i>created <xsl:value-of select="@created" /></i>
          </font>
        </th>

        <!-- DATE MODIFIED -->
        <th align="right">
          <font size="-2">
            <i>changed <xsl:value-of select="@changed" /></i>
          </font>
        </th>
      </tr>
    </table>

    <!-- ======================================================================= -->
    <!-- Array of values -->
    <p>
      <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">
      <tr>
        <!-- NAME/LABEL -->
        <th bgcolor="{$comment_color}" width="50%">
          <font style="text-transform:uppercase; font-size:large;">
            <xsl:value-of select="Name" />
            <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
          </font>
        </th>

        <!-- REFERENCE -->
        <th bgcolor="{$comment_color}" width="50%">
          <font style="text-transform: uppercase; font-size:large;">
            <xsl:value-of select="Reference" />
            <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
          </font>
        </th>
      </tr>
    </table>
    </p>
    
    <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">
      <!-- PRIX ET TAXE -->
      <tr>
        <th bgcolor="{$content_color}" align="right">
          <font style="text-transform: capitalize; font-size:large; font-weight: bold;">
            <xsl:text disable-output-escaping="yes">Prix</xsl:text>
          </font>
        </th>
        <th align="left">
          <xsl:value-of select="Price" /> &#8364;
        </th>
        <th bgcolor="{$content_color}" align="right">
          <font style="text-transform: capitalize; font-size:large; font-weight: bold;">
            <xsl:text disable-output-escaping="yes">Taxe</xsl:text>
          </font>
        </th>
        <th align="left">
          <xsl:value-of select="Tax" />%
        </th>
      </tr>

      <tr>
        <th colspan="4">
          <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
          <br />
        </th>
      </tr>

      <!-- DESCRIPTION -->
      <xsl:if test = "normalize-space(Description)">
        <tr>
          <th bgcolor="{$content_color}" align="right" colspan="2">
            <font style="text-transform: capitalize; font-size:large; font-weight: bold;">
              <xsl:text disable-output-escaping="yes">Description</xsl:text>
            </font>
          </th>
          <th align="left" colspan="2" width="50%">
            <xsl:value-of select="Description" />
          </th>
        </tr>
      </xsl:if>

      <!-- CODE -->
      <xsl:if test = "normalize-space(Code)">
        <tr>
          <th bgcolor="{$content_color}" align="right" colspan="2">
            <font style="text-transform: capitalize; font-size:large; font-weight: bold;">
              <xsl:text disable-output-escaping="yes">Code</xsl:text>
            </font>
          </th>
          <th align="left" colspan="2">
            <xsl:value-of select="Code" />
          </th>
        </tr>
      </xsl:if>

      <tr>
        <th colspan="4">
          <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
          <br />
        </th>
      </tr>

      <!-- == ... ======================================================================= -->
      <tr>
        <th colspan="2" valign="top" align="left" width="60%">
          <!-- NOTE : boucle sur les Lignes de la Note -->
          <code>
            <xsl:for-each select="Notes">
              <xsl:apply-templates select="Item" />
            </xsl:for-each>
          </code>
        </th>

        <th colspan="2" valign="top">
          <!-- IMAGE/LOGO DU PRODUIT -->
          <xsl:if test = "normalize-space(Logo)">
            <img src="{Logo}" style="width:350px; height:250px;" />
            <!-- Ajout retour à la ligne car lien Web après l'image -->
            <xsl:if test = "normalize-space(Web)">
              <br />
            </xsl:if>
          </xsl:if>

          <!-- WEB SITE -->
          <xsl:if test = "normalize-space(Web)">
            <a href="{Web}" target="_blank">
              <xsl:value-of select="Web" />
            </a>
          </xsl:if>
        </th>
      </tr>
      
      <!-- Closure of the Html table -->
    </table>

    <!-- 2 ===> Array of custom fields <=== -->
    <!-- Test the number of Nodes, as only non-empty information are to be treated -->
    <xsl:if test="count(Customs/Custom) > 0">
      <p>
        <table bgcolor="{$table2_color}" border="{$table2_border}" cellpadding="{$table2_padding}" cellspacing="{$table2_spacing}" width="100%">
        <tr>
          <th colspan="2" align="left" bgcolor="{$actionleft_color}">
            <font style="text-transform: capitalize; font-size:large; font-weight: bold;">
                <xsl:text disable-output-escaping="yes">additional information</xsl:text>
            </font>
          </th>
        </tr >

        <!-- Loop through the list of the Customs of the Xml file -->
        <xsl:for-each select="Customs">
          <xsl:apply-templates select="Custom" />
        </xsl:for-each>
        <!-- Closure of the Customs Html table -->
      </table >
      </p>
    </xsl:if>

    <!-- 3 ===> External links noticeboard <=== -->
    <!-- Test the number of Nodes, as only non-empty information are to be treated -->
    <xsl:if test="count(ExternalLinks/Link) > 0">
      <p>
        <table bgcolor="{$table2_color}" border="{$table2_border}" cellpadding="{$table2_padding}" cellspacing="{$table2_spacing}" width="100%">
        <tr>
          <th colspan="3" align="left" bgcolor="{$actionleft_color}">
            <font style="text-transform: capitalize; font-size:large; font-weight: bold;">
                <xsl:text disable-output-escaping="yes">external links</xsl:text>
            </font>
          </th>
        </tr >

        <!-- Loop through the list of external links in the Xml file -->
        <xsl:for-each select="ExternalLinks">
          <xsl:apply-templates select="Link" />
        </xsl:for-each>
        <!-- Closure of the Html of the external links table -->
      </table >
      </p>
    </xsl:if>

    <!-- 4 ===> Historical scoreboard <=== -->
    <!-- Test the number of Nodes, as only non-empty information are to be treated -->
    <xsl:if test="count(Historical/History) > 0">
      <p>
        <table bgcolor="{$table2_color}" border="{$table2_border}" cellpadding="{$table2_padding}" cellspacing="{$table2_spacing}" width="100%">
        <tr>
          <th colspan="3" align="left" bgcolor="{$actionleft_color}">
            <font style="text-transform: capitalize; font-size:large; font-weight: bold;">
                <xsl:text disable-output-escaping="yes">historical</xsl:text>
            </font>
          </th>
        </tr >

        <!-- Loop through the list of historical items in the Xml file -->
        <xsl:for-each select="Historical">
          <xsl:apply-templates select="History" />
        </xsl:for-each>
        <!-- Closure of the Html of the historical table -->
      </table >
      </p>
    </xsl:if>

  </xsl:template>

  <!--
   ==============================================================
    The called function to process the lines of a Note 
   ============================================================== -->
  <xsl:template match="Item">
    <xsl:value-of select="." />
    <br />
  </xsl:template>

  <!--
   ==========================================================================
    The called function to process the tree of the custom fields 
   ========================================================================== -->
  <xsl:template match="Custom">
    <xsl:if test = "normalize-space(Data)">
      <tr>
        <th bgcolor="{$content_color}" align="right">
          <!-- LABEL -->
          <xsl:value-of select="Label"/>
          <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
        </th>

        <th bgcolor="white" align="left">
          <!-- DATA -->
          <xsl:value-of select="Data" />
        </th>
      </tr>
    </xsl:if>
  </xsl:template>

  <!--
   =====================================================================
    The called function to process the tree of external links
   ===================================================================== -->
  <xsl:template match="Link">
    <xsl:if test = "normalize-space(Data)">
      <tr>
        <th style="text-align:center; background-color:{$content_color}; ">
          <!-- Category -->
          <xsl:value-of select="LinkCategory" />
        </th>

        <th align="left">
          <!-- DATA : lien effectif sur la donnée -->
          <xsl:choose>
            <!-- Fichier avec accès local -->
            <xsl:when test="@type= 'File'">
              <xsl:if test="normalize-space(Data)">
                <a href="file:///{Data}">
                  <xsl:value-of select="concat(substring-before(Data, '|') ,':', substring-after(Data, '|'))" />
                </a>
              </xsl:if>
            </xsl:when>

            <!-- Répertoire avec un accès local -->
            <xsl:when test="@type= 'Folder'">
              <xsl:if test="normalize-space(Data)">
                <a href="file:///{Data}">
                  <xsl:value-of select="concat(substring-before(Data, '|') ,':', substring-after(Data, '|'))" />
                </a>
              </xsl:if>
            </xsl:when>

            <!-- Application exécutable -->
            <xsl:when test="@type= 'Exe'">
              <xsl:if test="normalize-space(Data)">
                <a href="file:///{Data} {Parameters}" target="_blank">
                  <xsl:value-of select="Data" />
                  <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                  <xsl:value-of select="Parameters" />
                </a>
              </xsl:if>
            </xsl:when>

            <!-- URL: Web, FTP, etc. -->
            <xsl:when test="@type= 'Url'">
              <xsl:if test="normalize-space(Data)">
                <a href="{Data}{Parameters}" target="_blank">
                  <xsl:value-of disable-output-escaping="yes" select="Data" />
                  <xsl:value-of disable-output-escaping="yes" select="Parameters" />
                </a>
              </xsl:if>
            </xsl:when>

            <!-- Email -->
            <xsl:when test="@type= 'Mail'">
              <xsl:if test="normalize-space(Data)">
                <a href="mailto:{Data}">
                  <xsl:value-of select="Data" />
                </a>
              </xsl:if>
            </xsl:when>

            <!-- Fichier sur une Image -->
            <xsl:when test="@type= 'Image'">
              <xsl:if test="normalize-space(Data)">
                <img src="{Data}" width="100" height="100"/>
              </xsl:if>
            </xsl:when>

            <!-- Fichier sur une Image Web -->
            <xsl:when test="@type= 'ImageWeb'">
              <xsl:if test="normalize-space(Data)">
                <img src="{Data}" />
              </xsl:if>
            </xsl:when>

            <!-- Pas de traitement spécifique du lien -->
            <xsl:otherwise>
              <xsl:if test="normalize-space(Data)">
                <xsl:value-of select="Data" />
              </xsl:if>
            </xsl:otherwise>
          </xsl:choose>
        </th>
      </tr >

      <!-- NOTES : un descriptif optionel sur le lien -->
      <xsl:if test = "normalize-space(LinkNotes)">
        <tr>
          <th colspan="2" align="left">
            <code>
              <xsl:value-of select="LinkNotes" />
            </code>
          </th>
        </tr>
      </xsl:if>
    </xsl:if>
  </xsl:template>

  <!--
   ==========================================================================
    The called function to process the tree of the historical 
   ========================================================================== -->
  <xsl:template match="History">
    <tr>
      <th bgcolor="{$content_color}" align="middle">
        <!-- DATE -->
        <font size="-1">
          <xsl:value-of select="@date"/>
        </font>
      </th>

      <th bgcolor="white" align="left">
        <!-- LABEL -->
        <code>
          <xsl:value-of select="Data"/>
          <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
        </code>
      </th>

      <th bgcolor="{$comment_color}" align="middle">
        <!-- STATUS -->
        <font style="text-transform: capitalize; font-size:small;">
          <xsl:choose>
            <!-- Old treatment of the data -->
            <xsl:when test="Status= 'unDefined'">undefined</xsl:when>
            <xsl:when test="Status= 'Diferred'">diferred</xsl:when>
            <xsl:when test="Status= 'Failed'">failed</xsl:when>
            <xsl:when test="Status= 'Pending'">pending</xsl:when>
            <xsl:when test="Status= 'inProgress'">in progress</xsl:when>
            <xsl:when test="Status= 'notStarted'">not started</xsl:when>
            <xsl:when test="Status= 'Completed'">completed</xsl:when>
            <xsl:when test="Status= 'neverCompleted'">never completed</xsl:when>
            <!-- New treatment of the data -->
            <xsl:otherwise>
              <xsl:apply-templates select="Status" />
            </xsl:otherwise>
          </xsl:choose>
        </font>
      </th>
    </tr>
  </xsl:template>

  <xsl:template match="Status">
      <xsl:if test="@Label">
        <xsl:value-of select="@Label"/>
      </xsl:if>
  </xsl:template>

</xsl:stylesheet>



