<?xml version="1.0" encoding="iso-8859-1"?>

<!-- INVOICE: XML data to a HTML view formatting
 
 Bertrand Le Quellec (c) 2014-2016
 
 Version: 1.7 English Release
 
  Created: 2014-09-28
  Modification: 2013-10-30
  Modification: 2014-06-20 - mise  jour titre du type de document
  Modification: 2014-09-25 - ajout feuille de style de base
  Modification: 2014-10-21 - suppression feuille de style de base par des valeurs globales
  Modification: 2014-12-02 - mise  jour affichage liste produits/services et affichage adresse
  Modification: 2015-09-10 - prise en compte de l'affichage du Logo
  Modification: 2016-01-16 - rorganisation de l'affichage du total HT et correction Bug sur remise TTC
  Modification: 2016-03-17 - ajout taxe sur Livraison et alternance de couleur des lignes Produit
 
 Description:
 A generic Xml file from one Xml object data formatting Xsl file,
 representative structure an Invocie (Billing).
 -->

<xsl:stylesheet id="stylesheet" version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

  <!-- The variables indicating the Page Settings. -->
  <xsl:variable name="margin"              select="'2px'" />
  <xsl:variable name="padding"             select="'5px'" />
  <xsl:variable name="background_color"    select="'#F4FAFC'" />
  <xsl:variable name="font_size"           select="'75%'" />
  <xsl:variable name="font_family"         select="'Verdana, Geneva, Tahoma, sans-serif'" />

  <!-- The variables designating colours. -->
  <xsl:variable name="legendtop_color"     select="'Lavender'" />
  <xsl:variable name="legendleft_color"    select="'#B8CCEE'" />
  <xsl:variable name="rowseparator_color"  select="'Black'" />
  <xsl:variable name="content_color"       select="'#B8CCDC'" />
  <xsl:variable name="comment_color"       select="'#ffebcd'" />
  <xsl:variable name="actionleft_color"    select="'lightgrey'" />

  <!-- The variables for the formatting of the main tables. -->
  <xsl:variable name="table_color"         select="'#ffffff'" />
  <xsl:variable name="table_border"        select="'0'" />
  <xsl:variable name="table_spacing"       select="'1'" />
  <xsl:variable name="table_padding"       select="'0'" />
  <xsl:variable name="table_font"          select="'normal serif'" />

  <!-- The variables for the formatting of secondary tables. -->
  <xsl:variable name="table2_color"         select="'#ffffff'" />
  <xsl:variable name="table2_border"        select="'0'" />
  <xsl:variable name="table2_spacing"       select="'1'" />
  <xsl:variable name="table2_padding"       select="'0'" />

  <!-- The formatting of the html output method. -->
  <xsl:output
   method="html"
   encoding="ISO-8859-1"
   doctype-public="-//W3C//DTD HTML 4.01//EN"
   doctype-system="http://www.w3.org/TR/html4/strict.dtd"
   indent="yes" />

  <!-- Body of the HTML result: starting point. -->
  <xsl:template match="/">
    <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en">

      <head>
        <title>
          <xsl:value-of disable-output-escaping="yes" select="Invoice/Title" /> <xsl:value-of disable-output-escaping="yes" select="Invoice/Document_id" />
        </title>
        <meta name="description" content="Contact Manager - Invoice" />

        <meta name="publisher" content="BLQ software" />
        <meta name="author" content="BLQ software" />
        <meta name="copyright" content="BLQ software" />

        <meta name="http.language" content="English" />
        <meta name="Language" content="EN" />
        <meta http-equiv="Content-Language" content="en" />
      </head>

      <body style="margin:{$margin}; padding:{$padding}; background-color:{$background_color}; font-size:{$font_size}; font-family:{$font_family}; " >
        <!-- *********************************************
            Processing of the Xml root named Invoice 
           ********************************************* -->
        <xsl:apply-templates select="Invoice" />
      </body>
    </html>
  </xsl:template>

  <!-- 
   ===========================================
    INVOICE: first-level Xml processing 
   =========================================== -->
  <xsl:template match="Invoice">

    <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">
      <tr>
        <!-- LOGO -->
        <th bgcolor="white" valign="center">
          <xsl:choose>
            <xsl:when test="Logo">
              <img src="{Logo}" />
            </xsl:when>
            <xsl:otherwise>
              <!-- Insertion d'un espace si aucune valeur -->
              <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
            </xsl:otherwise>
          </xsl:choose>
        </th>

        <!-- INVOICE TYPE -->
        <th width="40%" align="left">
          <font style="text-transform: capitalize; font-size:x-large;">
            <b>
              <xsl:choose>
                <xsl:when test="@type= 'Quote'">
                  <xsl:text>quote</xsl:text>
                </xsl:when>
                <xsl:when test="@type= 'Invoice'">
                  <xsl:text>invoice</xsl:text>
                </xsl:when>
                <xsl:when test="@type= 'Order'">
                  <xsl:text>order</xsl:text>
                </xsl:when>
                <xsl:when test="@type= 'Receipt'">
                  <xsl:text>receipt</xsl:text>
                </xsl:when>
                <xsl:when test="@type= 'Delivry'">
                  <xsl:text>delivry</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                  <!-- Inserting a space instead of the empty table addresses -->
                  <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
            </b>
          </font>
        </th>
       
        <!-- CREATED DATE -->
        <th align="right">
          <font size="-2">
            <i>
              created <xsl:value-of select="@created" />
            </i>
          </font>
        </th>

        <!-- CHANGED DATE -->
        <th align="right">
          <font size="-2">
            <i>
              changed <xsl:value-of select="@changed" />
            </i>
          </font>
        </th>
      </tr>
      
      <tr>
        <!-- EMPTY COLUMN -->
        <th>
          <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
        </th>
        
        <!-- TITLE -->
        <th align="left">
          <xsl:choose>
            <xsl:when test="Title">
              <xsl:value-of select="Title" />
            </xsl:when>
            <xsl:otherwise>
              <!-- Inserting a space if no value -->
              <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
            </xsl:otherwise>
          </xsl:choose>
        </th>

        <!-- DOCUMENT ID -->
        <th align="right">
          <xsl:choose>
            <xsl:when test="Document_id">
              <xsl:value-of select="Document_id" />
            </xsl:when>
            <xsl:otherwise>
              <!-- Inserting a space if no value -->
              <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
            </xsl:otherwise>
          </xsl:choose>
        </th>

        <!-- OTHER REFERENCE -->
        <th align="right">
          <xsl:choose>
            <xsl:when test="Reference">
              <xsl:value-of select="Reference" />
            </xsl:when>
            <xsl:otherwise>
              <!-- Inserting a space if no value -->
              <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
            </xsl:otherwise>
          </xsl:choose>
        </th>
      </tr>
    </table>

    <!-- ADRESSES ======================================================================== 
    Retrieves the number of Nodes, as only non-empty information are to be treated
    ====================================================================================== -->
    <xsl:if test="count(Addresses)>0">
      <br />
      <!-- == ADDRESSES ======================================================================= -->
      <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">
        <tr >
          <th valign="top">
            <!-- The array of addresses will contain data -->
            <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">
              <tr >
                <!-- == SHIPPER ================================================================= -->
                  <th valign="top">
                    <table bgcolor="{$table2_color}" border="{$table2_border}" cellpadding="{$table2_padding}" cellspacing="{$table2_spacing}" width="100%">
                      <tr>
                        <th colspan="1" align="center" bgcolor="{$legendleft_color}">
                          <font style="text-transform:uppercase; font-weight:bold; ">shipper</font>
                        </th>
                      </tr >

                      <xsl:if test="Addresses/Shipper">
                        <!-- Shipper Loop -->
                        <xsl:for-each select="Addresses/Shipper/Item">
                        <tr >
                          <th align="left">
                            <code>
                              <!-- xsl:value-of select="Item" -->
                              <xsl:value-of select="substring-after(., ']|[')" />
                            </code>
                          </th>
                        </tr >
                      </xsl:for-each>
                      </xsl:if>
                    </table>
                  </th>

                <!-- == RECIPIENT ================================================================= -->
                  <th valign="top">
                    <table bgcolor="{$table2_color}" border="{$table2_border}" cellpadding="{$table2_padding}" cellspacing="{$table2_spacing}" width="100%">
                      <tr>
                        <th align="center" bgcolor="{$legendleft_color}">
                          <font style="text-transform: uppercase; font-weight: bold;">recipient</font>
                        </th>
                      </tr >

                      <xsl:if test="Addresses/Recipient">
                        <!-- Recipient LOOP -->
                        <xsl:for-each select="Addresses/Recipient/Item">
                        <tr >
                          <th align="left" >
                            <code>
                              <xsl:value-of select="substring-after(., ']|[')" />
                            </code>
                          </th>
                        </tr >
                      </xsl:for-each>
                      </xsl:if>
                    </table>
                  </th>

                <!-- == DELIVRY =================================================================== -->
                  <th valign="top">
                    <table bgcolor="{$table2_color}" border="{$table2_border}" cellpadding="{$table2_padding}" cellspacing="{$table2_spacing}" width="100%">
                      <tr>
                        <th align="center" bgcolor="{$legendleft_color}">
                          <font style="text-transform: uppercase; font-weight: bold;">delivry</font>
                        </th>
                      </tr >

                      <xsl:if test="Addresses/Delivry">
                        <!-- Delivry Loop -->
                        <xsl:for-each select="Addresses/Delivry/Item">
                        <tr >
                          <th align="left">
                            <code>
                              <xsl:value-of select="substring-after(., ']|[')" />
                            </code>
                          </th>
                        </tr >
                      </xsl:for-each>
                      </xsl:if>
                    </table>
                  </th>
              </tr>

              <!-- Closure of the addresses Html table -->
            </table >
          </th>
        </tr>
      </table>

    </xsl:if>

    <!-- PRODUCTS ======================================================================== -->
    <xsl:if test="count(Grid) > 0">
      <br />
      <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">

        <!-- == HEADERS ========================================================== -->
        <xsl:if test="Grid/Headers">
          <tr>
            <xsl:for-each select="Grid/Headers/GridCol">
              <th align="center" bgcolor="{$legendleft_color}">
                <b>
                  <xsl:value-of select="." />
                </b>
              </th>
            </xsl:for-each>
          </tr>
        </xsl:if>

        <!-- == CONTENT ========================================================== -->
        <xsl:if test="count(Grid/GridRows) > 0">
          <xsl:for-each select="Grid/GridRows">
            <xsl:apply-templates select="GridRow" />
          </xsl:for-each>
        </xsl:if>

        <!-- == TOTAL =========================================================== -->
        <tr >
          <th>
            <!-- Insertion of a space character -->
            <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
          </th>
          <th>
            <!-- Insertion of a space character -->
            <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
          </th>
          <th>
            <!-- Insertion of a space character -->
            <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
          </th>

          <xsl:if test="Quantity">
            <th valign="middle" align="center" bgcolor="{$comment_color}">
              <code>
                <xsl:value-of select="Quantity" />
              </code>
            </th>
          </xsl:if>

          <th>
            <!-- Insertion of a space charactere -->
            <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
          </th>

          <xsl:if test="Discount">
            <th valign="middle" align="right" bgcolor="{$comment_color}">
              <code>
                <xsl:value-of select="Discount" />
              </code>
            </th>
          </xsl:if>

          <xsl:if test="VAT">
            <th valign="middle" align="right" bgcolor="{$comment_color}">
              <code>
                <xsl:value-of select="VAT" />
              </code>
            </th>
          </xsl:if>

          <xsl:if test="Amount">
            <th valign="middle" align="right" bgcolor="{$comment_color}">
              <code>
                <xsl:value-of select="Amount" />
              </code>
            </th>
          </xsl:if>
        </tr>

      </table>
    </xsl:if>
    
    <!-- TAXES & DISCOUNT ================================================================ -->
    <p align="right">      
      <table bgcolor="{$table_color}" border="{$table_border}" cellpadding="{$table_padding}" cellspacing="{$table_spacing}" width="100%">

        <!-- SEPARATOR ========================================================================== -->
        <tr>
          <th bgcolor="{$rowseparator_color}" colspan="2"></th>
        </tr>

        <tr >
          <th align="left" valign="top">
            <!-- NOTES =========================================================================== -->
            <xsl:choose>
              <xsl:when test="Notes">
                <pre>
                  <xsl:value-of select="Notes" />
                </pre>
              </xsl:when>
              <xsl:otherwise>
                <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
              </xsl:otherwise>
            </xsl:choose>
          </th>

          <th valign="top" width="50%">
            <table bgcolor="{$table2_color}" border="{$table2_border}" cellpadding="{$table2_padding}" cellspacing="{$table2_spacing}" width="100%">

              <!-- TOTAL WITHOUT VAT -->
              <xsl:if test="Amount">
                <tr>
                  <th align="right" bgcolor="{$content_color}">
                    <font size="-1">
                      <xsl:value-of select="Amount/@Label" />
                    </font>
                  </th>
                  <th align="right">
                    <code>
                      <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                    </code>
                  </th>
                  <th align="right" bgcolor="{$content_color}">
                    <code>
                      <xsl:value-of select="Amount/Amount" />
                    </code>
                  </th>
                </tr>

                <!-- SEPARATOR ========================================================================== -->
                <tr>
                  <th bgcolor="{$rowseparator_color}" colspan="3"></th>
                </tr>
              </xsl:if>

              <!-- DISCOUNT : Global discount display without VAT -->
              <xsl:if test="count(GlobalDiscount)>0">
                <xsl:if test="GlobalDiscount/DiscountLessVAT">
                  <tr>
                    <th align="right" bgcolor="{$legendleft_color}">
                      <font size="-1">
                        <xsl:value-of select="GlobalDiscount/DiscountLessVAT/@Label" />
                      </font>
                    </th>
                    <th align="right">
                      <code>
                        <xsl:choose>
                          <xsl:when test="GlobalDiscount/DiscountLessVAT/@status= 'True'">
                            <xsl:value-of select="GlobalDiscount/DiscountLessVAT/Percent" /> %
                          </xsl:when>
                          <xsl:otherwise>
                            <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                          </xsl:otherwise>
                        </xsl:choose>
                      </code>
                    </th>
                    <th align="right" bgcolor="{$comment_color}">
                      <code>
                        <xsl:value-of select="GlobalDiscount/DiscountLessVAT/Amount" />
                      </code>
                    </th>
                  </tr>

                  <!-- SEPARATOR ========================================================================== -->
                  <tr>
                    <th bgcolor="{$rowseparator_color}" colspan="3"></th>
                  </tr>
                </xsl:if>
              </xsl:if>

              <!-- TAXE: Display of specific Taxes -->
              <xsl:if test="count(OtherTax)>0">
                <xsl:if test="OtherTax/OtherTax1">
                  <tr>
                    <xsl:apply-templates select="OtherTax/OtherTax1" />
                  </tr>
                </xsl:if>
                <xsl:if test="OtherTax/OtherTax2">
                  <tr>
                    <xsl:apply-templates select="OtherTax/OtherTax2" />
                  </tr>
                </xsl:if>
                <xsl:if test="OtherTax/OtherTax3">
                  <tr>
                    <xsl:apply-templates select="OtherTax/OtherTax3" />
                  </tr>
                </xsl:if>

                <!-- SEPARATOR ========================================================================== -->
                <tr>
                  <th bgcolor="{$rowseparator_color}" colspan="3"></th>
                </tr>
              </xsl:if>

              <!-- DISCOUNT: Global discount display with VAT -->
              <xsl:if test="count(GlobalDiscount)>0">
                <xsl:if test="GlobalDiscount/DiscountPlusVAT">
                  <tr>
                    <th align="right" bgcolor="{$legendleft_color}">
                      <font size="-1">
                        <xsl:value-of select="GlobalDiscount/DiscountPlusVAT/@Label" />
                      </font>
                    </th>
                    <th align="right">
                      <code>
                        <xsl:choose>
                          <xsl:when test="GlobalDiscount/DiscountPlusVAT/@status= 'True'">
                            <xsl:value-of select="GlobalDiscount/DiscountPlusVAT/Percent" /> %
                          </xsl:when>
                          <xsl:otherwise>
                            <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                          </xsl:otherwise>
                        </xsl:choose>
                      </code>
                    </th>
                    <th align="right" bgcolor="{$comment_color}">
                      <code>
                        <xsl:value-of select="GlobalDiscount/DiscountPlusVAT/Amount" />
                      </code>
                    </th>
                  </tr>

                  <!-- SEPARATOR ========================================================================== -->
                  <tr>
                    <th bgcolor="{$rowseparator_color}" colspan="3"></th>
                  </tr>
                </xsl:if>
              </xsl:if>

              <!-- INSURANCE AND DELIVERY CHARGES ON TOTAL WITH VAT -->
              <xsl:if test="Insurrance">
                <tr>
                  <th align="right" bgcolor="{$legendleft_color}">
                    <font size="-1">
                      <xsl:value-of select="Insurrance/@Label" />
                    </font>
                  </th>
                  <th align="right">
                    <code>
                      <xsl:choose>
                        <xsl:when test="Insurrance/@status= 'True'">
                          <xsl:value-of select="Insurrance/Percent" /> %
                        </xsl:when>
                        <xsl:otherwise>
                          <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                        </xsl:otherwise>
                      </xsl:choose>
                    </code>
                  </th>
                  <th align="right" bgcolor="{$comment_color}">
                    <code>
                      <xsl:value-of select="Insurrance/Amount" />
                    </code>
                  </th>
                </tr>
              </xsl:if>

              <xsl:if test="Delivry">
                <tr>
                  <th align="right" bgcolor="{$legendleft_color}">
                    <font size="-1">
                      <xsl:value-of select="Delivry/@Label" />
                    </font>
                  </th>
                  <th align="right">
                    <code>
                      <xsl:choose>
                        <xsl:when test="Delivry/@status= 'True'">
                          <xsl:value-of select="Delivry/Percent" /> %
                        </xsl:when>
                        <xsl:otherwise>
                          <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                        </xsl:otherwise>
                      </xsl:choose>
                    </code>
                  </th>
                  <th align="right" bgcolor="{$comment_color}">
                    <code>
                      <xsl:value-of select="Delivry/Amount" />
                    </code>
                  </th>
                </tr>
                
                <!-- TAXE LIVRAISON -->
                <xsl:if test="DelivryTax">
                  <tr>
                    <th align="right" bgcolor="{$legendleft_color}">
                      <font size="-1">
                        <xsl:value-of select="DelivryTax/@Label" />
                      </font>
                    </th>
                    <th align="right">
                      <code>
                        <xsl:choose>
                          <xsl:when test="DelivryTax/@status= 'True'">
                            <xsl:value-of select="DelivryTax/Percent" /> %
                          </xsl:when>
                          <xsl:otherwise>
                            <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                          </xsl:otherwise>
                        </xsl:choose>
                      </code>
                    </th>
                    <th align="right" bgcolor="{$comment_color}">
                      <code>
                        <xsl:value-of select="DelivryTax/Amount" />
                      </code>
                    </th>
                  </tr>
                </xsl:if>
                  
                <!-- SEPARATOR ========================================================================== -->
                <tr>
                  <th bgcolor="{$rowseparator_color}" colspan="3"></th>
                </tr>
              </xsl:if>

              <!-- FEE SERVICE -->
              <xsl:if test="Service">
                <tr>
                  <th align="right" bgcolor="{$legendleft_color}">
                    <font size="-1">
                      <xsl:value-of select="Service/@Label" />
                    </font>
                  </th>
                  <th align="right">
                    <code>
                      <xsl:choose>
                        <xsl:when test="Service/@status= 'True'">
                          <xsl:value-of select="Service/Percent" /> %
                        </xsl:when>
                        <xsl:otherwise>
                          <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                        </xsl:otherwise>
                      </xsl:choose>
                    </code>
                  </th>
                  <th align="right" bgcolor="{$comment_color}">
                    <code>
                      - <xsl:value-of select="Service/Amount" />
                    </code>
                  </th>
                </tr>
              </xsl:if>

              <!-- DEPOSIT ALREADY PAY -->
              <xsl:if test="Deposit">
                <tr>
                  <th align="right" bgcolor="{$legendleft_color}">
                    <font size="-1">
                      <xsl:value-of select="Deposit/@Label" />
                    </font>
                  </th>
                  <th align="right">
                    <code>
                      <xsl:choose>
                        <xsl:when test="Deposit/@status= 'True'">
                          <xsl:value-of select="Deposit/Percent" /> %
                        </xsl:when>
                        <xsl:otherwise>
                          <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                        </xsl:otherwise>
                      </xsl:choose>
                    </code>
                  </th>
                  <th align="right" bgcolor="{$comment_color}">
                    <code>
                      - <xsl:value-of select="Deposit/Amount" />
                    </code>
                  </th>
                </tr>
              </xsl:if>

              <!-- TOTAL INCLUSIVE OF VAT TO PAY -->
              <xsl:if test="TotalAmount">
                <tr>
                  <th bgcolor="{$rowseparator_color}" colspan="3"></th>
                </tr>
                <tr>
                  <th align="right" bgcolor="{$content_color}">
                    <font size="-1">
                      <xsl:value-of select="TotalAmount/@Label" />
                    </font>
                  </th>
                  <th align="right">
                    <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
                  </th>
                  <th align="right" bgcolor="{$content_color}">
                    <code>
                      <xsl:value-of select="TotalAmount/Amount" />
                    </code>
                  </th>
                </tr>
              </xsl:if>
            </table>
          </th>
        </tr>

        <!-- SEPARATOR ========================================================================== -->
        <tr>
          <th bgcolor="{$rowseparator_color}" colspan="3"></th>
        </tr>
      </table>
    </p>

    <!-- CUSTOM INFORMATION ============================================================== -->
    <xsl:if test="count(Customs/Custom) > 0">
      <!-- CUSTOMIZATION ===================================================================== -->
      <table bgcolor="{$table2_color}" border="{$table2_border}" cellpadding="{$table2_padding}" cellspacing="{$table2_spacing}" width="100%">
        <xsl:for-each select="Customs">
          <xsl:apply-templates select="Custom" />
        </xsl:for-each>
      </table>
    </xsl:if>

  </xsl:template>

  <!-- SPECIFICS TAXES ============================================================ -->
  <xsl:template match="OtherTax1">
    <xsl:if test="@status= 'True'">
      <th align="right" bgcolor="{$legendleft_color}">
        <font size="-1">
          <xsl:value-of select="@Label" />
        </font>
      </th>
      <th align="right">
        <code>
          <xsl:value-of select="Percent" /> %
        </code>
      </th>
      <th align="right" bgcolor="{$comment_color}">
        <code>
          <xsl:value-of select="Amount" />
        </code>
      </th>
    </xsl:if>
  </xsl:template>

  <xsl:template match="OtherTax2">
    <xsl:if test="@status= 'True'">
      <th align="right" bgcolor="{$legendleft_color}">
        <font size="-1">
          <xsl:value-of select="@Label" />
        </font>
      </th>
      <th align="right">
        <code>
          <xsl:value-of select="Percent" /> %
        </code>
      </th>
      <th align="right" bgcolor="{$comment_color}">
        <code>
          <xsl:value-of select="Amount" />
        </code>
      </th>
    </xsl:if>
  </xsl:template>

  <xsl:template match="OtherTax3">
    <xsl:if test="@status= 'True'">
      <th align="right" bgcolor="{$legendleft_color}">
        <font size="-1">
          <xsl:value-of select="@Label" />
        </font>
      </th>
      <th align="right">
        <code>
          <xsl:value-of select="Percent" /> %
        </code>
      </th>
      <th align="right" bgcolor="{$comment_color}">
        <code>
          <xsl:value-of select="Amount" />
        </code>
      </th>
    </xsl:if>
  </xsl:template>

  <!-- PRODUCT/SERVICE ============================================================ -->
  <xsl:template match="GridRow">
    <tr >
      <!-- Alternance des couleurs de fond de chaque ligne  -->
      <xsl:if test="position() mod 2 = 0">
        <xsl:attribute name="bgcolor">lightgrey</xsl:attribute>
        <!-- 
        En cas de passage d'une couleur incluse dans une variable globale : $actionleft_color
        la couleur visualise est diffrente ! Donc la couleur est directement crite
        A explorer plus tard... -->
      </xsl:if>
      
      <xsl:for-each select="GridCol">
        <th align="center">
          <code>
            <xsl:value-of select="." />
            <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
          </code>
        </th>
      </xsl:for-each>
    </tr>
  </xsl:template>

  <!-- CUSTOM VALUES ============================================================== -->
  <xsl:template match="Custom">
    <xsl:if test = "normalize-space(Data)">
      <tr>
        <!-- LABEL -->
        <th bgcolor="{$content_color}" align="right" style="width:30%;">
          <xsl:value-of select="Label"/>
          <xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
        </th>

        <!-- DATA -->
        <th align="left">
          <xsl:value-of select="Data" />
        </th>
      </tr>
    </xsl:if>
  </xsl:template>
  
</xsl:stylesheet>



